package com.taauav.admin.controller;

import com.taauav.common.bean.Response;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import com.taauav.common.core.mps.BaseQuery;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.taauav.admin.entity.UserAdmin;
import com.taauav.admin.service.IFrontUserAdminService;

/**
 * 外包人员Controller
 *
 * @author daixiantong
 * @date 20200521
 */
@RestController
@RequestMapping("/admin/userAdmin")
public class FrontUserAdminController extends BaseController {
    @Autowired
    private IFrontUserAdminService userAdminService;

    @Autowired
    private Response response;

    /**
     * 查询外包人员列表
     */
    @RequiresPermissions("admin:admin:list")
    @GetMapping("/list")
    public Response list(UserAdmin userAdmin, BaseQuery query) {
        return userAdminService.pageData(query, userAdmin);
    }


    /**
     * 获取外包人员详细信息
     */
    @RequiresPermissions("admin:admin:query")
    @GetMapping(value = "/{id}")
    public Response getInfo(@PathVariable("id") Integer id) {
        return response.success(userAdminService.getInfo(id));
    }

    /**
     * 新增外包人员
     */
    @RequiresPermissions("admin:admin:add")
    @PostMapping
    public Response add(@RequestBody UserAdmin userAdmin) {
        return response.success(userAdminService.save(userAdmin));
    }

    /**
     * 修改外包人员
     */
    @RequiresPermissions("admin:admin:edit")
    @PutMapping
    public Response edit(@RequestBody UserAdmin userAdmin) {
        return response.success(userAdminService.updateById(userAdmin));
    }

    /**
     * 删除外包人员
     */
    @RequiresPermissions("admin:admin:remove")
    @DeleteMapping("/{ids}")
    public Response remove(@PathVariable Integer[] ids) {
        return response.success(userAdminService.deleteByIds(ids, new UserAdmin()));
    }

    /**
     * 获取河长列表
     */
    @PostMapping("/getDriverManagerList")
    public Response getDriverManagerList() {
        return userAdminService.getDriverManagerList();
    }
}
