package com.taauav.admin.service.impl;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.taauav.admin.dto.TauvWaterWarnDTO;
import com.taauav.admin.entity.SysCity;
import com.taauav.admin.mapper.SysCityMapper;
import com.taauav.common.bean.Response;
import com.taauav.common.core.mps.BaseQuery;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import com.taauav.common.util.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.taauav.admin.mapper.TauvWaterWarnMapper;
import com.taauav.admin.entity.TauvWaterWarn;
import com.taauav.admin.service.ITauvWaterWarnService;

import javax.annotation.Resource;
import java.math.BigInteger;

/**
 * 水质预警Service业务层处理
 *
 * @author daixiantong
 * @date 20200514
 */
@Service
public class TauvWaterWarnServiceImpl extends BaseServiceImpl<TauvWaterWarnMapper, TauvWaterWarn> implements ITauvWaterWarnService
{
    @Resource
    private Response response;
    @Autowired
    private SysCityMapper cityMapper;

    /**
     * 自定义列表
     * @param waterWarnDTO
     * @param query
     * @return
     */
    @Override
    public Response selectWarnPageList(TauvWaterWarnDTO waterWarnDTO, BaseQuery query) {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("mark", 1);
        if (StringUtils.isNotEmpty(waterWarnDTO.getWarnSn())) {
            wrapper.like("warn_sn", waterWarnDTO.getWarnSn());
        }
        if (StringUtils.isNotEmpty(waterWarnDTO.getDriverName())) {
            wrapper.like("driver_name", waterWarnDTO.getDriverName());
        }
        if (StringUtils.isNotNull(waterWarnDTO.getDriverArea()) && waterWarnDTO.getDriverArea().compareTo(BigInteger.ZERO) > 0) {
            wrapper.eq("driver_area", waterWarnDTO.getDriverArea());
        }
        if (StringUtils.isNotNull(waterWarnDTO.getStatus()) && waterWarnDTO.getStatus() > 0) {
            wrapper.eq("status", waterWarnDTO.getStatus());
        }
        if (StringUtils.isNotNull(waterWarnDTO.getStartTime()) && StringUtils.isNotNull(waterWarnDTO.getEndTime())) {
            String beginTime = FunctionUtils.dateToString(waterWarnDTO.getStartTime(), "yyyy-MM-dd");
            String endTime = FunctionUtils.dateToString(waterWarnDTO.getEndTime(), "yyyy-MM-dd");
            if (!beginTime.isEmpty() && !endTime.isEmpty()) {
                wrapper.between("inspect_time", beginTime, endTime);
            }
        }
        wrapper.orderByDesc("id");
        IPage<TauvWaterWarn> list = pageData(query, wrapper);
        if (list.getRecords().size() > 0) {
            for (TauvWaterWarn data : list.getRecords()) {
                data.setWarnTypeText(FunctionUtils.getArrayText(data.getWarnType().toString(), data.typeList()));
                data.setWarnLevelText(FunctionUtils.getArrayText(data.getWarnLevel().toString(), data.levelList()));
                data.setStatusText(FunctionUtils.getArrayText(data.getStatus().toString(), data.statusList()));
                SysCity city = cityMapper.selectById(data.getDriverArea());
                data.setAreaName(city != null ? city.getName() : "");
            }
        }
        return response.success(list);
    }

    /**
     * 取消预警
     * @param ids
     * @return
     */
    @Override
    public Response cancelWarn(String ids) {
        UpdateWrapper updateWrapper = new UpdateWrapper();
        updateWrapper.in("id", ids);
        updateWrapper.eq("mark", 1);
        updateWrapper.set("status", 3);
        updateWrapper.set("update_user", ShiroUtils.getAdminId());
        updateWrapper.set("update_time", DateUtil.now());
        Boolean res = update(updateWrapper);
        if (!res) {
            return response.failure("操作失败");
        }
        return response.success("操作成功");
    }

    /**
     * 删除预警数据
     * @param ids
     * @return
     */
    @Override
    public Response dropWarn(String ids) {
        UpdateWrapper updateWrapper = new UpdateWrapper();
        updateWrapper.in("id", ids);
        updateWrapper.set("mark", 0);
        Boolean result = update(updateWrapper);
        if (!result) {
            return response.failure("删除失败");
        }
        return response.success("删除成功");
    }
}
