package com.taauav.front.controller;

import com.taauav.common.bean.Response;
import com.taauav.common.util.RedisUtils;
import com.taauav.common.util.VerifyUtil;
import com.taauav.front.dto.LoginDto;
import com.taauav.front.service.IUserLoginService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

@RestController
@RequestMapping("/front/login")
public class UserLoginController {

    @Autowired
    private IUserLoginService loginService;
    @Autowired
    private RedisUtils redisUtils;
    @Autowired
    private Response response;

    /**
     * 系统登录
     *
     * @param loginDto 参数
     * @return
     */
    @PostMapping("/login")
    public Response login(@RequestBody LoginDto loginDto) {
        return loginService.login(loginDto);
    }

    /**
     * 图片验证码
     *
     * @param resp
     * @return
     */
    @GetMapping("/captcha")
    public Response captcha(HttpServletResponse resp) {
        VerifyUtil verifyUtil = new VerifyUtil();
        Map result = new HashMap();
        try {
            String key = UUID.randomUUID().toString();
            resp.setContentType("image/png");
            resp.setHeader("Cache-Control", "no-cache");
            resp.setHeader("Expire", "0");
            resp.setHeader("Pragma", "no-cache");
            // 返回base64
            //写入redis缓存
            Map<String, String> mapInfo = verifyUtil.getRandomCodeBase64();
            String randomStr = mapInfo.get("randomStr");
            redisUtils.set(key, randomStr, 60 * 5);

            result.put("url", "data:image/png;base64," + mapInfo.get("img"));
            result.put("key", key);
        } catch (Exception e) {
            return response.failure(e.getMessage());
        }
        return response.success(result);
    }

}
