package com.taauav.front.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.taauav.admin.entity.SysCity;
import com.taauav.admin.entity.TauvInspectQuestion;
import com.taauav.admin.mapper.SysCityMapper;
import com.taauav.admin.service.ISysCityService;
import com.taauav.common.bean.Response;
import com.taauav.front.mapper.UserInspectQuestionMapper;
import com.taauav.front.mapper.UserWaterAlarmInfoMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/front/screen")
public class UserScreenStatisticsController {

    @Autowired
    private UserInspectQuestionMapper inspectQuestionMapper;
    @Autowired
    private ISysCityService cityService;
    @Autowired
    private SysCityMapper cityMapper;
    @Autowired
    private UserWaterAlarmInfoMapper waterAlarmInfoMapper;
    @Autowired
    private Response response;

    /**
     * 大屏统计
     *
     * @return
     */
    @GetMapping("/index")
    public Response index() {
        // 巡检问题处理情况统计
        Map<String, Object> inspectQuestionInfo = getInspectQuestionInfo();
        // 获取待处理污染
        List<Map<String, Object>> waitQuestionInfo = getCategoryQuestionInfo();
        // 巡检问题河湖统计
        List<Map<String, Object>> questionDriverList = inspectQuestionMapper.getQuestionDriverList();
        // 获取区属问题统计
        List<Map<String, Object>> questionDriverAreaList = getQuestionDriverAreaList();
        // 获取河湖水质问题分类统计
        List<Map<String, String>> waterAlarmCategoryList = getWaterAlarmCategoryList();

        // 返回结果
        Map<String, Object> result = new HashMap<>();
        result.put("inspectQuestionInfo", inspectQuestionInfo);
        result.put("waitQuestionInfo", waitQuestionInfo);
        result.put("questionDriverList", questionDriverList);
        result.put("questionDriverAreaList", questionDriverAreaList);
        result.put("waterAlarmCategoryList", waterAlarmCategoryList);
        return response.success(result);
    }

    /**
     * 巡检问题处理情况统计
     *
     * @return
     */
    private Map<String, Object> getInspectQuestionInfo() {
        Map<String, Object> result = new HashMap<>();
        // 获取已发现问题数
        Integer totalNum = inspectQuestionMapper.selectCount(new LambdaQueryWrapper<TauvInspectQuestion>()
                .eq(TauvInspectQuestion::getMark, 1));
        result.put("totalNum", totalNum);
        // 获取已解决问题数
        Integer finishedNum = inspectQuestionMapper.selectCount(new LambdaQueryWrapper<TauvInspectQuestion>()
                .eq(TauvInspectQuestion::getStatus, 3)
                .eq(TauvInspectQuestion::getMark, 1));
        result.put("finishedNum", finishedNum);
        // 已处理占比
        if (totalNum > 0) {
            result.put("percentage", String.format("%.2f", (float) finishedNum / (float) totalNum * 100));
        } else {
            result.put("percentage", "0.00%");
        }
        return result;
    }

    /**
     * 获取待处理污染问题统计
     *
     * @return
     */
    private List<Map<String, Object>> getCategoryQuestionInfo() {
        String category = "1=水面,2=岸线,3=排口,4=水质";
        String[] strings = category.split(",");
        List<Map<String, Object>> mapList = new ArrayList<>();
        for (String string : strings) {
            String[] strings1 = string.split("=");

            Map<String, Object> categoryMap = inspectQuestionMapper.getCategoryQuestionInfo(Integer.valueOf(strings1[0]));
            Map<String, Object> map = new HashMap<>();
            map.put("name", strings1[1]);
            if (categoryMap != null) {
                map.put("totalNum", categoryMap.get("total_num"));
            } else {
                map.put("totalNum", 0);
            }
            mapList.add(map);
        }
        return mapList;
    }

    /**
     * 获取区属问题河湖统计
     *
     * @return
     */
    private List<Map<String, Object>> getQuestionDriverAreaList() {
        List<Map<String, Object>> mapList = inspectQuestionMapper.getQuestionDriverAreaList();
        List<String> stringList = new ArrayList<>();
        if (!mapList.isEmpty()) {
            mapList.forEach(item -> {
                stringList.add(item.get("id").toString());
            });
        }

        QueryWrapper<SysCity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("pid", 3201);
        queryWrapper.eq("mark", 1);
        List<SysCity> cityList = cityMapper.selectList(queryWrapper);
        if (!cityList.isEmpty()) {
            cityList.forEach(item -> {
                if (!stringList.contains(item.getId().toString())) {
                    Map<String, Object> map = new HashMap<>();
                    map.put("id", item.getId());
                    map.put("name", item.getName());
                    map.put("num", 0);
                    mapList.add(map);
                }
            });
        }
        return mapList;
    }

    /**
     * 河湖水质问题分类统计
     *
     * @return
     */
    private List<Map<String, String>> getWaterAlarmCategoryList() {
        List<Map<String, Object>> mapList = waterAlarmInfoMapper.getWaterAlarmCategoryList();
        List<Map<String, String>> result = new ArrayList<>();
        Integer totalNum = 0;
        if (!mapList.isEmpty()) {
            for (Map<String, Object> map : mapList) {
                totalNum += Integer.valueOf(map.get("totalNum").toString());
            }
            if (totalNum > 0) {
                // 计算百分比
                for (Map<String, Object> map : mapList) {
                    Map<String, String> item = new HashMap<>();
                    item.put("name", map.get("name").toString());
                    item.put("value", String.format("%.2f", (float) Integer.valueOf(map.get("totalNum").toString()) / (float) totalNum * 100));
                    result.add(item);
                }
            }
        }
        return result;
    }

}
